At startup it compile theme and minify js sources. You have to use it to serve these assets to the client.
How to use
You have to add these routes to your project
use viewy::engine::Assets;
#[get("/app.css")]
fn get_stylesheet(assets: rocket::State<Assets>) -> Css<String> {
Css(assets.inner().clone().stylesheet)
}
#[get("/app.js")]
fn get_scripts(assets: rocket::State<Assets>) -> JavaScript<String> {
JavaScript(assets.inner().clone().script)
}And add an Assets instance to rocket state
rocket::ignite()
.manage(rocket::Assets::new())Fields
script: Stringstylesheet: StringImplementations